==> ukui-greeter_1.2.5.orig.tar.gz: ukui-greeter/ukui-greeter/translations/ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>BioAuthentication</name>
    <message>
        <source>authentication failed, restart after 2 seconds</source>
        <translation type="obsolete">не удалось идентифицировать, перезапустить после 2 секунды</translation>
    </message>
</context>
<context>
    <name>BioDeviceView</name>
    <message>
        <source>password login</source>
        <translation type="obsolete">пароль и логин</translation>
    </message>
    <message>
        <source>fingerprint</source>
        <translation type="obsolete">отпечатки пальцев</translation>
    </message>
    <message>
        <source>fingerevin</source>
        <translation type="obsolete">палец эвин</translation>
    </message>
    <message>
        <source>iris</source>
        <translation type="obsolete">айрис</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="100"/>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="163"/>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="48"/>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="53"/>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="67"/>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="75"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="37"/>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="39"/>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="41"/>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="43"/>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="45"/>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FakeDialog</name>
    <message>
        <location filename="../common/fakedialog.cpp" line="63"/>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GreeterWrapper</name>
    <message>
        <location filename="../greeter/greeterwrapper.cpp" line="102"/>
        <source>failed to start session.</source>
        <translation>не начала сессии.</translation>
    </message>
</context>
<context>
    <name>IconEdit</name>
    <message>
        <source>Login</source>
        <translation type="obsolete">вход</translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <location filename="../VirtualKeyboard/src/keyboardwidget.ui" line="29"/>
        <source>KeyboardWidget</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginWindow</name>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="264"/>
        <location filename="../greeter/loginwindow.cpp" line="573"/>
        <source>Login</source>
        <translation>вход</translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="309"/>
        <source>logged in</source>
        <translation>войти в систему</translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="390"/>
        <location filename="../greeter/loginwindow.cpp" line="482"/>
        <source>login</source>
        <translation>вход</translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="478"/>
        <source>Password: </source>
        <translation>пароль: </translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="480"/>
        <source>login:</source>
        <translation>вход:</translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="537"/>
        <source>Incorrect user name, please input again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="578"/>
        <location filename="../greeter/loginwindow.cpp" line="785"/>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="751"/>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="763"/>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="775"/>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="542"/>
        <location filename="../greeter/loginwindow.cpp" line="547"/>
        <source>Incorrect password, please input again</source>
        <translation type="unfinished">неверный пароль, пожалуйста, введите снова</translation>
    </message>
    <message>
        <source>please select the type of authentication</source>
        <translation type="obsolete">пожалуйста, выберите тип аутентификации</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../display-switch/ui_mainwindow.h" line="127"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerWindow</name>
    <message>
        <source>Goodbye. Would you like to…</source>
        <translation type="obsolete">до свидания.хотели бы вы...</translation>
    </message>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="54"/>
        <source>Goodbye. Would you like to...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="57"/>
        <source>Other users are currently logged in to this computer, shutting down now will also close these other sessions.</source>
        <translation>другие пользователи, в настоящее время вход в этот компьютер, закрыв теперь будет также закрыть эти другие занятия.</translation>
    </message>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="156"/>
        <source>suspend</source>
        <translation>приостановить</translation>
    </message>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="170"/>
        <source>hibernate</source>
        <translation>гибернация</translation>
    </message>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="184"/>
        <source>restart</source>
        <translation>перезагрузка</translation>
    </message>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="198"/>
        <source>shutdown</source>
        <translation>остановка</translation>
    </message>
</context>
<context>
    <name>SessionWindow</name>
    <message>
        <source>select the desktop environment</source>
        <translation type="obsolete">выберите окружение рабочего стола</translation>
    </message>
    <message>
        <source> (Default)</source>
        <translation type="vanished">(по умолчанию)</translation>
    </message>
</context>
<context>
    <name>UserEntry</name>
    <message>
        <source>logged in</source>
        <translation type="vanished">войти в систему</translation>
    </message>
</context>
<context>
    <name>UsersModel</name>
    <message>
        <location filename="../greeter/usersmodel.cpp" line="42"/>
        <location filename="../greeter/usersmodel.cpp" line="44"/>
        <source>Guest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/usersmodel.cpp" line="52"/>
        <source>Guest Session</source>
        <translation>гость.</translation>
    </message>
    <message>
        <location filename="../greeter/usersmodel.cpp" line="70"/>
        <location filename="../greeter/usersmodel.cpp" line="72"/>
        <location filename="../greeter/usersmodel.cpp" line="79"/>
        <source>Login</source>
        <translation>вход</translation>
    </message>
</context>
</TS>

==> ukui-greeter_3.0.1.orig.tar.gz: ukui-greeter/ukui-greeter/translations/ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>BioAuthentication</name>
    <message>
        <source>authentication failed, restart after 2 seconds</source>
        <translation type="obsolete">не удалось идентифицировать, перезапустить после 2 секунды</translation>
    </message>
</context>
<context>
    <name>BioDeviceView</name>
    <message>
        <source>password login</source>
        <translation type="obsolete">пароль и логин</translation>
    </message>
    <message>
        <source>fingerprint</source>
        <translation type="obsolete">отпечатки пальцев</translation>
    </message>
    <message>
        <source>fingerevin</source>
        <translation type="obsolete">палец эвин</translation>
    </message>
    <message>
        <source>iris</source>
        <translation type="obsolete">айрис</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="100"/>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="163"/>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="50"/>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="55"/>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="72"/>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="82"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="37"/>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="39"/>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="41"/>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="43"/>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="45"/>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FakeDialog</name>
    <message>
        <location filename="../common/fakedialog.cpp" line="63"/>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GreeterWrapper</name>
    <message>
        <location filename="../greeter/greeterwrapper.cpp" line="105"/>
        <source>failed to start session.</source>
        <translation>не начала сессии.</translation>
    </message>
</context>
<context>
    <name>IconEdit</name>
    <message>
        <source>Login</source>
        <translation type="obsolete">вход</translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <location filename="../VirtualKeyboard/src/keyboardwidget.ui" line="29"/>
        <source>KeyboardWidget</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginWindow</name>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="267"/>
        <location filename="../greeter/loginwindow.cpp" line="575"/>
        <source>Login</source>
        <translation>вход</translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="312"/>
        <source>logged in</source>
        <translation>войти в систему</translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="392"/>
        <source>login</source>
        <translation>вход</translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="480"/>
        <source>Password: </source>
        <translation>пароль: </translation>
    </message>
    <message>
        <source>login:</source>
        <translation type="vanished">вход:</translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="482"/>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="539"/>
        <source>Incorrect user name, please input again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="580"/>
        <location filename="../greeter/loginwindow.cpp" line="789"/>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="754"/>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="767"/>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="779"/>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="544"/>
        <location filename="../greeter/loginwindow.cpp" line="549"/>
        <source>Incorrect password, please input again</source>
        <translation type="unfinished">неверный пароль, пожалуйста, введите снова</translation>
    </message>
    <message>
        <source>please select the type of authentication</source>
        <translation type="obsolete">пожалуйста, выберите тип аутентификации</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../display-switch/ui_mainwindow.h" line="127"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="131"/>
        <source>Switch User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="144"/>
        <source>Sleep</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="158"/>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="172"/>
        <source>Power Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>suspend</source>
        <translation type="obsolete">приостановить</translation>
    </message>
    <message>
        <source>restart</source>
        <translation type="obsolete">перезагрузка</translation>
    </message>
    <message>
        <source>shutdown</source>
        <translation type="obsolete">остановка</translation>
    </message>
</context>
<context>
    <name>PowerWindow</name>
    <message>
        <source>Goodbye. Would you like to…</source>
        <translation type="obsolete">до свидания.хотели бы вы...</translation>
    </message>
    <message>
        <source>Other users are currently logged in to this computer, shutting down now will also close these other sessions.</source>
        <translation type="vanished">другие пользователи, в настоящее время вход в этот компьютер, закрыв теперь будет также закрыть эти другие занятия.</translation>
    </message>
    <message>
        <source>suspend</source>
        <translation type="vanished">приостановить</translation>
    </message>
    <message>
        <source>hibernate</source>
        <translation type="vanished">гибернация</translation>
    </message>
    <message>
        <source>restart</source>
        <translation type="vanished">перезагрузка</translation>
    </message>
    <message>
        <source>shutdown</source>
        <translation type="vanished">остановка</translation>
    </message>
</context>
<context>
    <name>SessionWindow</name>
    <message>
        <source>select the desktop environment</source>
        <translation type="obsolete">выберите окружение рабочего стола</translation>
    </message>
    <message>
        <source> (Default)</source>
        <translation type="vanished">(по умолчанию)</translation>
    </message>
</context>
<context>
    <name>UserEntry</name>
    <message>
        <source>logged in</source>
        <translation type="vanished">войти в систему</translation>
    </message>
</context>
<context>
    <name>UsersModel</name>
    <message>
        <location filename="../greeter/usersmodel.cpp" line="42"/>
        <location filename="../greeter/usersmodel.cpp" line="44"/>
        <source>Guest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/usersmodel.cpp" line="52"/>
        <source>Guest Session</source>
        <translation>гость.</translation>
    </message>
    <message>
        <location filename="../greeter/usersmodel.cpp" line="70"/>
        <location filename="../greeter/usersmodel.cpp" line="72"/>
        <location filename="../greeter/usersmodel.cpp" line="79"/>
        <source>Login</source>
        <translation>вход</translation>
    </message>
</context>
</TS>
